@@ -363,13 +363,9 @@ try {
   std::vector<int> founder_labels;
 
   if (input_population_1[0] > -1e4) {
-    if (verbose) { Rcout << "Found input populations\n";  force_output(); }
-
     Pop_1 = convert_NumericVector_to_fishVector(input_population_1);
     Pop_2 = convert_NumericVector_to_fishVector(input_population_2);
 
-    if (verbose) { Rcout << "done converting\n"; force_output(); }
-
     for (auto it = Pop_1.begin(); it != Pop_1.end(); ++it) {
       update_founder_labels((*it).chromosome1, founder_labels);
       update_founder_labels((*it).chromosome2, founder_labels);
@@ -380,11 +376,9 @@ try {
       update_founder_labels((*it).chromosome2, founder_labels);
     }
 
-    if (verbose) { Rcout << "updated founder labels\n"; force_output(); }
     number_of_alleles = founder_labels.size();
 
     if (Pop_1.size() != pop_size[0]) {
-      if (verbose)  { Rcout << "drawing pop 1: " << pop_size[0] << " from: " << Pop_1.size() << "\n"; force_output(); }
       // the populations have to be populated from the parents!
       std::vector< Fish > Pop_1_new;
       for(int j = 0; j < pop_size[0]; ++j) {
@@ -394,13 +388,9 @@ try {
       Pop_1 = Pop_1_new;
       Pop_1_new.clear(); // free up memory
     }
-    if (verbose) { Rcout << "drawn pop 1\n"; force_output(); }
 
     if (Pop_2.size() != pop_size[1]) {
       std::vector< Fish > Pop_2_new;
-      if (verbose) { Rcout << "drawing pop 2: " << pop_size[1] << "\n";
-                     force_output();
-      }
       for (int j = 0; j < pop_size[1]; ++j) {
         int index = rndgen.random_number(Pop_2.size());
         Pop_2_new.push_back(Pop_2[index]);
@@ -408,11 +398,7 @@ try {
       Pop_2 = Pop_2_new;
       Pop_2_new.clear(); // free up memory
     }
-    if (verbose) {Rcout << "drawn pop 2\n"; force_output();}
   } else {
-    if (verbose) {
-      Rcout << "generating from scratch\n"; force_output();
-    }
 
     for (int j = 0; j < 2; ++j) {
       for (int i = 0; i < pop_size[j]; ++i) {
@@ -428,16 +414,12 @@ try {
         if(j == 1) Pop_2.push_back(mate(p1, p2, morgan, rndgen));
       }
     }
-    if (verbose) {
-      Rcout << "collecting all founder labels\n"; force_output();
-    }
     for (int i = 0; i < starting_frequencies.ncol(); ++i) {
       founder_labels.push_back(i);
     }
     number_of_alleles = founder_labels.size();
   }
 
-  if (verbose) { Rcout << "initial frequencies\n"; force_output();}
   int number_of_markers = track_markers.size();
   // 5 columns: time, loc, anc, type, population
   arma::mat frequencies_table(number_of_markers * number_of_alleles * total_runtime * 2, 5);
