@@ -362,8 +362,6 @@ List simulate_migration_emp_cpp(const NumericMatrix& input_population_1,
 try {
   rnd_t rndgen;
 
-  if (verbose) { Rcout << "entered cpp\n"; force_output();}
-
   std::vector< Fish_emp > Pop_1;
   std::vector< Fish_emp > Pop_2;
   std::vector<int> founder_labels = {0, 1, 2, 3, 4};
@@ -380,7 +378,6 @@ try {
   pop_size[1] = static_cast<size_t>(pop_sizes[1]);
 
   int number_of_markers = track_markers.size();
-  if (verbose) Rcout << "number_of_markers: " << number_of_markers << "\n";
 
   emp_genome emp_gen(marker_positions);
   if (static_cast<size_t>(recombination_map.size()) ==
@@ -405,7 +402,6 @@ try {
   }
 
   if (input_population_1[0] > -1e4) {
-    if (verbose) { Rcout << "Found input populations\n";  force_output(); }
 
     if (pop_size.size() != 2) {
       stop("pop_size.size() != 2, need two separate population sizes as input");
@@ -414,15 +410,8 @@ try {
     Pop_1 = convert_numeric_matrix_to_fish_vector(input_population_1);
     Pop_2 = convert_numeric_matrix_to_fish_vector(input_population_2);
 
-    if (verbose) { Rcout << "done converting\n"; force_output(); }
-    if (verbose) { Rcout << "pop1: " << Pop_1.size() << "\n"; force_output(); }
-    if (verbose) { Rcout << "pop2: " << Pop_2.size() << "\n"; force_output(); }
-    if (verbose) { Rcout << pop_size[0] << " " << pop_size[1] << "\n"; force_output(); }
-
     if (static_cast<size_t>(Pop_1.size()) !=
         static_cast<size_t>(pop_size[0])) {
-      if (verbose) {Rcout << "drawing pop 1: " << pop_size[0] <<
-        " from: " << Pop_1.size() << "\n"; force_output(); }
       //   the populations have to be populated from the parents!
       std::vector< Fish_emp > Pop_1_new(pop_size[0]);
       for(size_t j = 0; j < pop_size[0]; ++j) {
@@ -430,29 +419,17 @@ try {
         Pop_1_new[j] = Pop_1[index];
       }
     }
-    if (verbose)  {Rcout << "drawn pop 1\n"; force_output();}
-
     if (static_cast<size_t>(Pop_2.size()) !=
         static_cast<size_t>(pop_size[1])) {
       std::vector< Fish_emp > Pop_2_new(pop_size[1]);
-      if (verbose) { Rcout << "drawing pop 2: " << pop_size[1] << " " <<
-        Pop_2.size() << "\n"; force_output(); }
       for (int j = 0; j < pop_size[1]; ++j) {
         int index = rndgen.random_number(Pop_2.size());
         Pop_2_new[j] = Pop_2[index];
       }
       Pop_2 = Pop_2_new;
     }
-
-    if (verbose) {Rcout << "drawing done: " << Pop_1.size() << " " <<
-      Pop_2.size() << "\n"; force_output();}
   }
 
-  if (verbose) {Rcout << "input_data loaded\n"; force_output();}
-
-  if (verbose) {Rcout << "initial frequencies\n"; force_output();}
-
-  if (verbose) {Rcout << track_markers.size() << "\n"; force_output(); }
   // 5 columns: time, loc, anc, type, population
   arma::mat frequencies_table(number_of_markers * number_of_alleles * total_runtime * 2, 5);
   arma::mat initial_frequencies = update_all_frequencies_tibble_dual_pop(Pop_1,
