@@ -2,7 +2,6 @@ context("simulate_admixture")
 
 test_that("simulate_admixture", {
   testthat::skip_on_os("solaris")
-  message("test simulate_admixture 1")
   select_matrix <- matrix(NA, nrow = 2, ncol = 5)
 
   s <- 0.1
@@ -22,7 +21,6 @@ test_that("simulate_admixture", {
 
 test_that("simulate admixture use", {
   testthat::skip_on_os("solaris")
-  message("test simulate admixture use")
   testthat::expect_output(
     vx <- simulate_admixture(pop_size = 100,
                              module = ancestry_module(number_of_founders = 2,
@@ -103,7 +101,6 @@ test_that("simulate admixture use", {
 
 test_that("simulate admixture use, junctions", {
   testthat::skip_on_os("solaris")
-  message("simulate admixture use, junctions")
   vx <- simulate_admixture(module = ancestry_module(track_junctions = TRUE),
                            pop_size = 1000,
                            total_runtime = 100)
@@ -115,7 +112,6 @@ test_that("simulate admixture use, junctions", {
 
 test_that("simulate admixture use, markers", {
   testthat::skip_on_os("solaris")
-  message("test simulate admixture use, markers")
   pop <- simulate_admixture(module = ancestry_module(markers =
                                                        seq(0,
                                                            1,
@@ -161,7 +157,6 @@ test_that("simulate admixture use, markers", {
 
 test_that("simulate admixture use, pop size", {
   testthat::skip_on_os("solaris")
-  message("simulate admixture use, pop size")
   pop <- simulate_admixture(pop_size = 100,
                             total_runtime = 3)
 
